@@ -2,40 +2,44 @@ use syn::__private::Span;
 
 use crate::{DebugPls, Formatter};
 
+pub(crate) fn process(value: &dyn DebugPls) -> String {
+    let output = prettyplease::unparse(&syn::File {
+        shebang: None,
+        attrs: vec![],
+        items: vec![syn::Item::Const(syn::ItemConst {
+            expr: Box::new(Formatter::process(value)),
+            // junk...
+            attrs: vec![],
+            vis: syn::Visibility::Inherited,
+            const_token: syn::token::Const::default(),
+            ident: syn::Ident::new("_", Span::call_site()),
+            colon_token: syn::token::Colon::default(),
+            ty: Box::new(syn::Type::Tuple(syn::TypeTuple {
+                paren_token: syn::token::Paren::default(),
+                elems: syn::punctuated::Punctuated::default(),
+            })),
+            eq_token: syn::token::Eq::default(),
+            semi_token: syn::token::Semi::default(),
+        })],
+    });
+
+    // strip out the junk
+    let output = &output[14..];
+    let output = &output[..output.len() - 2];
+    textwrap::dedent(output)
+}
+
 struct PolyFill(dyn DebugPls);
 
 impl std::fmt::Debug for PolyFill {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let output = prettyplease::unparse(&syn::File {
-            shebang: None,
-            attrs: vec![],
-            items: vec![syn::Item::Const(syn::ItemConst {
-                expr: Box::new(Formatter::process(&self.0)),
-                // junk...
-                attrs: vec![],
-                vis: syn::Visibility::Inherited,
-                const_token: syn::token::Const::default(),
-                ident: syn::Ident::new("_", Span::call_site()),
-                colon_token: syn::token::Colon::default(),
-                ty: Box::new(syn::Type::Tuple(syn::TypeTuple {
-                    paren_token: syn::token::Paren::default(),
-                    elems: syn::punctuated::Punctuated::default(),
-                })),
-                eq_token: syn::token::Eq::default(),
-                semi_token: syn::token::Semi::default(),
-            })],
-        });
-
-        // strip out the junk
-        let output = &output[14..];
-        let output = &output[..output.len() - 2];
-        f.write_str(&textwrap::dedent(output))
+        f.write_str(&process(&self.0))
     }
 }
 
 impl std::fmt::Display for PolyFill {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        std::fmt::Debug::fmt(&self, f)
+        std::fmt::Debug::fmt(self, f)
     }
 }
 
